#!/bin/bash

# Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
# DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
#
# This code is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 2 only, as
# published by the Free Software Foundation.
#
# This code is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# version 2 for more details (a copy is included in the LICENSE file that
# accompanied this code).
#
# You should have received a copy of the GNU General Public License version
# 2 along with this work; if not, write to the Free Software Foundation,
# Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
# or visit www.oracle.com if you need additional information or have any
# questions.

# The conversion relies on patching the mercurial convert extension slightly to
# better handle conversion of merge changesets. This script downloads the
# tested version of mercurial, applies the patch and builds it so that unify.py
# can use it

MERCURIAL_VERSION=4.1
MERCURIAL_DIR=mercurial-${MERCURIAL_VERSION}
MERCURIAL_PKG=${MERCURIAL_DIR}.tar.gz

mydir="$(dirname "${BASH_SOURCE[0]}")"
mydir="$(cd "${mydir}" && pwd)"

mkdir -p ${mydir}/mercurial
cd ${mydir}/mercurial

if [ ! -e ${MERCURIAL_PKG} ]; then
    wget https://www.mercurial-scm.org/release/${MERCURIAL_PKG}
fi
rm -rf ${MERCURIAL_DIR}
tar xf ${MERCURIAL_PKG}
cd ${MERCURIAL_DIR}
patch -p1 < ${mydir}/mercurial.patch
make -j 8 local
