#!/usr/bin/python3

# Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
# DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
#
# This code is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 2 only, as
# published by the Free Software Foundation.
#
# This code is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# version 2 for more details (a copy is included in the LICENSE file that
# accompanied this code).
#
# You should have received a copy of the GNU General Public License version
# 2 along with this work; if not, write to the Free Software Foundation,
# Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
# or visit www.oracle.com if you need additional information or have any
# questions.

import os
import sys

import hgcommon

def initialize(r, src_repos, start_tag):
    r.init()

    repos = hgcommon.repos_with_tag(src_repos, start_tag)

    r.pullConvert(repos[0], start_tag)
    r.update()
    target_node = r.nodes('tip')[0]

    for src_repo in repos[1:]:
        r.pullConvert(src_repo, start_tag, target_node, '0')
        r.update('tip')
        r.merge()
    r.tag(start_tag)

if len(sys.argv) < 3 :
    print("Usage: python3 unify.py <src> <dest> [<end tag>]")
    sys.exit(1)

src = os.path.abspath(sys.argv[1])
dest = os.path.abspath(sys.argv[2])
r = hgcommon.Repository(dest)
src_repos = hgcommon.defineSrcRepos(src)

if len(sys.argv) > 3:
    stop_tag = sys.argv[3]
else:
    stop_tag = None

tags = []
src_tags = src_repos[0].tags()
if not os.path.exists(dest):
    initialize(r, src_repos, 'jdk7-b24')
    tags = src_tags[1:] # first tag already processed
else:
    # the unified repo already exists, find out new tags to pull in
    dest_tags = r.tags()
    tags = src_tags[len(dest_tags):]

if stop_tag:
    tags = tags[:tags.index(stop_tag) + 1]

print("tags to pull: %s" % str(tags))

for tag in tags:
    repos = hgcommon.repos_with_tag(src_repos, tag)
    for src_repo in repos:
        # Find the most recent previous tag in this repo
        last_tag, splice_revs = hgcommon.most_recent_prev_tag(src_repo, tag, src_tags)
        if r.pullConvert(src_repo, tag, last_tag, splice_revs):
            r.update('tip')
            r.merge()
    r.tag(tag)
r.update()
