#!/usr/bin/python3

# Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
# DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
#
# This code is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 2 only, as
# published by the Free Software Foundation.
#
# This code is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# version 2 for more details (a copy is included in the LICENSE file that
# accompanied this code).
#
# You should have received a copy of the GNU General Public License version
# 2 along with this work; if not, write to the Free Software Foundation,
# Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
# or visit www.oracle.com if you need additional information or have any
# questions.

import sys
from os.path import abspath, join

import hgcommon

if len(sys.argv) < 3:
    print("Usage: python3 verify.py <forest> <unified> [<start tag>]")
    sys.exit(1)

if len(sys.argv) > 3:
    start_tag = sys.argv[3]
else:
    start_tag = None

top = abspath(sys.argv[1])
src_repos = hgcommon.defineSrcRepos(abspath(top))
unified_repo = abspath(sys.argv[2])

r = hgcommon.Repository(unified_repo)
tags = src_repos[0].tags()

if start_tag:
    tags = tags[tags.index(start_tag):]

for tag in tags:
    r.update(tag)
    repos_with_tag = hgcommon.repos_with_tag(src_repos, tag)
    for repo in repos_with_tag:
        repo.update(tag)
    x = ''
    for repo in src_repos:
        if repo not in repos_with_tag:
            x += ' -x ' + repo.shortname
    out = hgcommon.sh('diff -r -x .hg -x .hgtags -x .hgtags-top-repo %s %s %s' \
             % (x, top, unified_repo)).decode('utf-8')
    if out != '':
        print("Tree differ on tag %s:" % (tag))
        print(out)
    else:
        print("Tree is identical for tag %s" % (tag))
